
.. _user_guide:

==========
User Guide
==========

Welcome to sktime's user guide!

The purpose of the user guide is to provide a scientific manual for the
methods implemented in sktime. The :ref:`api_reference`, by contrast, is
meant to provide a technical manual.


.. note::

    The user guide is under development. We have created a basic
    structure and are looking for contributions to develop the user guide
    further. For more details, please go to issue `#361 <https://github
    .com/alan-turing-institute/sktime/issues/361>`_ on GitHub.


.. toctree::
   :maxdepth: 1

   user_guide/introduction
   user_guide/learning_tasks
   user_guide/transformations
   user_guide/classification
   user_guide/regression
   user_guide/forecasting
   user_guide/clustering
   user_guide/annotation
   user_guide/performance_metrics
   user_guide/resources
